@@ -6,9 +6,9 @@ Type annotations for kafka service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kafka.type_defs import BatchAssociateScramSecretRequestTypeDef
+    from mypy_boto3_kafka.type_defs import BatchAssociateScramSecretRequestRequestTypeDef
 
-    data: BatchAssociateScramSecretRequestTypeDef = {...}
+    data: BatchAssociateScramSecretRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -36,10 +36,10 @@ else:
 
 
 __all__ = (
-    "BatchAssociateScramSecretRequestTypeDef",
-    "BatchAssociateScramSecretResponseResponseTypeDef",
-    "BatchDisassociateScramSecretRequestTypeDef",
-    "BatchDisassociateScramSecretResponseResponseTypeDef",
+    "BatchAssociateScramSecretRequestRequestTypeDef",
+    "BatchAssociateScramSecretResponseTypeDef",
+    "BatchDisassociateScramSecretRequestRequestTypeDef",
+    "BatchDisassociateScramSecretResponseTypeDef",
     "BrokerEBSVolumeInfoTypeDef",
     "BrokerLogsTypeDef",
     "BrokerNodeGroupInfoTypeDef",
@@ -55,52 +55,52 @@ __all__ = (
     "ConfigurationInfoTypeDef",
     "ConfigurationRevisionTypeDef",
     "ConfigurationTypeDef",
-    "CreateClusterRequestTypeDef",
-    "CreateClusterResponseResponseTypeDef",
-    "CreateConfigurationRequestTypeDef",
-    "CreateConfigurationResponseResponseTypeDef",
-    "DeleteClusterRequestTypeDef",
-    "DeleteClusterResponseResponseTypeDef",
-    "DeleteConfigurationRequestTypeDef",
-    "DeleteConfigurationResponseResponseTypeDef",
-    "DescribeClusterOperationRequestTypeDef",
-    "DescribeClusterOperationResponseResponseTypeDef",
-    "DescribeClusterRequestTypeDef",
-    "DescribeClusterResponseResponseTypeDef",
-    "DescribeConfigurationRequestTypeDef",
-    "DescribeConfigurationResponseResponseTypeDef",
-    "DescribeConfigurationRevisionRequestTypeDef",
-    "DescribeConfigurationRevisionResponseResponseTypeDef",
+    "CreateClusterRequestRequestTypeDef",
+    "CreateClusterResponseTypeDef",
+    "CreateConfigurationRequestRequestTypeDef",
+    "CreateConfigurationResponseTypeDef",
+    "DeleteClusterRequestRequestTypeDef",
+    "DeleteClusterResponseTypeDef",
+    "DeleteConfigurationRequestRequestTypeDef",
+    "DeleteConfigurationResponseTypeDef",
+    "DescribeClusterOperationRequestRequestTypeDef",
+    "DescribeClusterOperationResponseTypeDef",
+    "DescribeClusterRequestRequestTypeDef",
+    "DescribeClusterResponseTypeDef",
+    "DescribeConfigurationRequestRequestTypeDef",
+    "DescribeConfigurationResponseTypeDef",
+    "DescribeConfigurationRevisionRequestRequestTypeDef",
+    "DescribeConfigurationRevisionResponseTypeDef",
     "EBSStorageInfoTypeDef",
     "EncryptionAtRestTypeDef",
     "EncryptionInTransitTypeDef",
     "EncryptionInfoTypeDef",
     "ErrorInfoTypeDef",
     "FirehoseTypeDef",
-    "GetBootstrapBrokersRequestTypeDef",
-    "GetBootstrapBrokersResponseResponseTypeDef",
-    "GetCompatibleKafkaVersionsRequestTypeDef",
-    "GetCompatibleKafkaVersionsResponseResponseTypeDef",
+    "GetBootstrapBrokersRequestRequestTypeDef",
+    "GetBootstrapBrokersResponseTypeDef",
+    "GetCompatibleKafkaVersionsRequestRequestTypeDef",
+    "GetCompatibleKafkaVersionsResponseTypeDef",
     "IamTypeDef",
     "JmxExporterInfoTypeDef",
     "JmxExporterTypeDef",
     "KafkaVersionTypeDef",
-    "ListClusterOperationsRequestTypeDef",
-    "ListClusterOperationsResponseResponseTypeDef",
-    "ListClustersRequestTypeDef",
-    "ListClustersResponseResponseTypeDef",
-    "ListConfigurationRevisionsRequestTypeDef",
-    "ListConfigurationRevisionsResponseResponseTypeDef",
-    "ListConfigurationsRequestTypeDef",
-    "ListConfigurationsResponseResponseTypeDef",
-    "ListKafkaVersionsRequestTypeDef",
-    "ListKafkaVersionsResponseResponseTypeDef",
-    "ListNodesRequestTypeDef",
-    "ListNodesResponseResponseTypeDef",
-    "ListScramSecretsRequestTypeDef",
-    "ListScramSecretsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "ListClusterOperationsRequestRequestTypeDef",
+    "ListClusterOperationsResponseTypeDef",
+    "ListClustersRequestRequestTypeDef",
+    "ListClustersResponseTypeDef",
+    "ListConfigurationRevisionsRequestRequestTypeDef",
+    "ListConfigurationRevisionsResponseTypeDef",
+    "ListConfigurationsRequestRequestTypeDef",
+    "ListConfigurationsResponseTypeDef",
+    "ListKafkaVersionsRequestRequestTypeDef",
+    "ListKafkaVersionsResponseTypeDef",
+    "ListNodesRequestRequestTypeDef",
+    "ListNodesResponseTypeDef",
+    "ListScramSecretsRequestRequestTypeDef",
+    "ListScramSecretsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "LoggingInfoTypeDef",
     "MutableClusterInfoTypeDef",
     "NodeExporterInfoTypeDef",
@@ -111,45 +111,45 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PrometheusInfoTypeDef",
     "PrometheusTypeDef",
-    "RebootBrokerRequestTypeDef",
-    "RebootBrokerResponseResponseTypeDef",
+    "RebootBrokerRequestRequestTypeDef",
+    "RebootBrokerResponseTypeDef",
     "ResponseMetadataTypeDef",
     "S3TypeDef",
     "SaslTypeDef",
     "ScramTypeDef",
     "StateInfoTypeDef",
     "StorageInfoTypeDef",
-    "TagResourceRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TlsTypeDef",
     "UnprocessedScramSecretTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateBrokerCountRequestTypeDef",
-    "UpdateBrokerCountResponseResponseTypeDef",
-    "UpdateBrokerStorageRequestTypeDef",
-    "UpdateBrokerStorageResponseResponseTypeDef",
-    "UpdateBrokerTypeRequestTypeDef",
-    "UpdateBrokerTypeResponseResponseTypeDef",
-    "UpdateClusterConfigurationRequestTypeDef",
-    "UpdateClusterConfigurationResponseResponseTypeDef",
-    "UpdateClusterKafkaVersionRequestTypeDef",
-    "UpdateClusterKafkaVersionResponseResponseTypeDef",
-    "UpdateConfigurationRequestTypeDef",
-    "UpdateConfigurationResponseResponseTypeDef",
-    "UpdateMonitoringRequestTypeDef",
-    "UpdateMonitoringResponseResponseTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateBrokerCountRequestRequestTypeDef",
+    "UpdateBrokerCountResponseTypeDef",
+    "UpdateBrokerStorageRequestRequestTypeDef",
+    "UpdateBrokerStorageResponseTypeDef",
+    "UpdateBrokerTypeRequestRequestTypeDef",
+    "UpdateBrokerTypeResponseTypeDef",
+    "UpdateClusterConfigurationRequestRequestTypeDef",
+    "UpdateClusterConfigurationResponseTypeDef",
+    "UpdateClusterKafkaVersionRequestRequestTypeDef",
+    "UpdateClusterKafkaVersionResponseTypeDef",
+    "UpdateConfigurationRequestRequestTypeDef",
+    "UpdateConfigurationResponseTypeDef",
+    "UpdateMonitoringRequestRequestTypeDef",
+    "UpdateMonitoringResponseTypeDef",
     "ZookeeperNodeInfoTypeDef",
 )
 
-BatchAssociateScramSecretRequestTypeDef = TypedDict(
-    "BatchAssociateScramSecretRequestTypeDef",
+BatchAssociateScramSecretRequestRequestTypeDef = TypedDict(
+    "BatchAssociateScramSecretRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "SecretArnList": List[str],
     },
 )
 
-BatchAssociateScramSecretResponseResponseTypeDef = TypedDict(
-    "BatchAssociateScramSecretResponseResponseTypeDef",
+BatchAssociateScramSecretResponseTypeDef = TypedDict(
+    "BatchAssociateScramSecretResponseTypeDef",
     {
         "ClusterArn": str,
         "UnprocessedScramSecrets": List["UnprocessedScramSecretTypeDef"],
@@ -157,16 +157,16 @@ BatchAssociateScramSecretResponseResponseTypeDef = TypedDict(
     },
 )
 
-BatchDisassociateScramSecretRequestTypeDef = TypedDict(
-    "BatchDisassociateScramSecretRequestTypeDef",
+BatchDisassociateScramSecretRequestRequestTypeDef = TypedDict(
+    "BatchDisassociateScramSecretRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "SecretArnList": List[str],
     },
 )
 
-BatchDisassociateScramSecretResponseResponseTypeDef = TypedDict(
-    "BatchDisassociateScramSecretResponseResponseTypeDef",
+BatchDisassociateScramSecretResponseTypeDef = TypedDict(
+    "BatchDisassociateScramSecretResponseTypeDef",
     {
         "ClusterArn": str,
         "UnprocessedScramSecrets": List["UnprocessedScramSecretTypeDef"],
@@ -379,8 +379,8 @@ ConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateClusterRequestTypeDef = TypedDict(
-    "_RequiredCreateClusterRequestTypeDef",
+_RequiredCreateClusterRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateClusterRequestRequestTypeDef",
     {
         "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
         "ClusterName": str,
@@ -388,8 +388,8 @@ _RequiredCreateClusterRequestTypeDef = TypedDict(
         "NumberOfBrokerNodes": int,
     },
 )
-_OptionalCreateClusterRequestTypeDef = TypedDict(
-    "_OptionalCreateClusterRequestTypeDef",
+_OptionalCreateClusterRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateClusterRequestRequestTypeDef",
     {
         "ClientAuthentication": "ClientAuthenticationTypeDef",
         "ConfigurationInfo": "ConfigurationInfoTypeDef",
@@ -403,14 +403,14 @@ _OptionalCreateClusterRequestTypeDef = TypedDict(
 )
 
 
-class CreateClusterRequestTypeDef(
-    _RequiredCreateClusterRequestTypeDef, _OptionalCreateClusterRequestTypeDef
+class CreateClusterRequestRequestTypeDef(
+    _RequiredCreateClusterRequestRequestTypeDef, _OptionalCreateClusterRequestRequestTypeDef
 ):
     pass
 
 
-CreateClusterResponseResponseTypeDef = TypedDict(
-    "CreateClusterResponseResponseTypeDef",
+CreateClusterResponseTypeDef = TypedDict(
+    "CreateClusterResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterName": str,
@@ -419,15 +419,15 @@ CreateClusterResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateConfigurationRequestTypeDef = TypedDict(
-    "_RequiredCreateConfigurationRequestTypeDef",
+_RequiredCreateConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateConfigurationRequestRequestTypeDef",
     {
         "Name": str,
         "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
     },
 )
-_OptionalCreateConfigurationRequestTypeDef = TypedDict(
-    "_OptionalCreateConfigurationRequestTypeDef",
+_OptionalCreateConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateConfigurationRequestRequestTypeDef",
     {
         "Description": str,
         "KafkaVersions": List[str],
@@ -436,14 +436,15 @@ _OptionalCreateConfigurationRequestTypeDef = TypedDict(
 )
 
 
-class CreateConfigurationRequestTypeDef(
-    _RequiredCreateConfigurationRequestTypeDef, _OptionalCreateConfigurationRequestTypeDef
+class CreateConfigurationRequestRequestTypeDef(
+    _RequiredCreateConfigurationRequestRequestTypeDef,
+    _OptionalCreateConfigurationRequestRequestTypeDef,
 ):
     pass
 
 
-CreateConfigurationResponseResponseTypeDef = TypedDict(
-    "CreateConfigurationResponseResponseTypeDef",
+CreateConfigurationResponseTypeDef = TypedDict(
+    "CreateConfigurationResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -454,14 +455,14 @@ CreateConfigurationResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteClusterRequestTypeDef = TypedDict(
-    "_RequiredDeleteClusterRequestTypeDef",
+_RequiredDeleteClusterRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteClusterRequestRequestTypeDef",
     {
         "ClusterArn": str,
     },
 )
-_OptionalDeleteClusterRequestTypeDef = TypedDict(
-    "_OptionalDeleteClusterRequestTypeDef",
+_OptionalDeleteClusterRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteClusterRequestRequestTypeDef",
     {
         "CurrentVersion": str,
     },
@@ -469,14 +470,14 @@ _OptionalDeleteClusterRequestTypeDef = TypedDict(
 )
 
 
-class DeleteClusterRequestTypeDef(
-    _RequiredDeleteClusterRequestTypeDef, _OptionalDeleteClusterRequestTypeDef
+class DeleteClusterRequestRequestTypeDef(
+    _RequiredDeleteClusterRequestRequestTypeDef, _OptionalDeleteClusterRequestRequestTypeDef
 ):
     pass
 
 
-DeleteClusterResponseResponseTypeDef = TypedDict(
-    "DeleteClusterResponseResponseTypeDef",
+DeleteClusterResponseTypeDef = TypedDict(
+    "DeleteClusterResponseTypeDef",
     {
         "ClusterArn": str,
         "State": ClusterStateType,
@@ -484,15 +485,15 @@ DeleteClusterResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteConfigurationRequestTypeDef = TypedDict(
-    "DeleteConfigurationRequestTypeDef",
+DeleteConfigurationRequestRequestTypeDef = TypedDict(
+    "DeleteConfigurationRequestRequestTypeDef",
     {
         "Arn": str,
     },
 )
 
-DeleteConfigurationResponseResponseTypeDef = TypedDict(
-    "DeleteConfigurationResponseResponseTypeDef",
+DeleteConfigurationResponseTypeDef = TypedDict(
+    "DeleteConfigurationResponseTypeDef",
     {
         "Arn": str,
         "State": ConfigurationStateType,
@@ -500,45 +501,45 @@ DeleteConfigurationResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeClusterOperationRequestTypeDef = TypedDict(
-    "DescribeClusterOperationRequestTypeDef",
+DescribeClusterOperationRequestRequestTypeDef = TypedDict(
+    "DescribeClusterOperationRequestRequestTypeDef",
     {
         "ClusterOperationArn": str,
     },
 )
 
-DescribeClusterOperationResponseResponseTypeDef = TypedDict(
-    "DescribeClusterOperationResponseResponseTypeDef",
+DescribeClusterOperationResponseTypeDef = TypedDict(
+    "DescribeClusterOperationResponseTypeDef",
     {
         "ClusterOperationInfo": "ClusterOperationInfoTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeClusterRequestTypeDef = TypedDict(
-    "DescribeClusterRequestTypeDef",
+DescribeClusterRequestRequestTypeDef = TypedDict(
+    "DescribeClusterRequestRequestTypeDef",
     {
         "ClusterArn": str,
     },
 )
 
-DescribeClusterResponseResponseTypeDef = TypedDict(
-    "DescribeClusterResponseResponseTypeDef",
+DescribeClusterResponseTypeDef = TypedDict(
+    "DescribeClusterResponseTypeDef",
     {
         "ClusterInfo": "ClusterInfoTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeConfigurationRequestTypeDef = TypedDict(
-    "DescribeConfigurationRequestTypeDef",
+DescribeConfigurationRequestRequestTypeDef = TypedDict(
+    "DescribeConfigurationRequestRequestTypeDef",
     {
         "Arn": str,
     },
 )
 
-DescribeConfigurationResponseResponseTypeDef = TypedDict(
-    "DescribeConfigurationResponseResponseTypeDef",
+DescribeConfigurationResponseTypeDef = TypedDict(
+    "DescribeConfigurationResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -551,16 +552,16 @@ DescribeConfigurationResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeConfigurationRevisionRequestTypeDef = TypedDict(
-    "DescribeConfigurationRevisionRequestTypeDef",
+DescribeConfigurationRevisionRequestRequestTypeDef = TypedDict(
+    "DescribeConfigurationRevisionRequestRequestTypeDef",
     {
         "Arn": str,
         "Revision": int,
     },
 )
 
-DescribeConfigurationRevisionResponseResponseTypeDef = TypedDict(
-    "DescribeConfigurationRevisionResponseResponseTypeDef",
+DescribeConfigurationRevisionResponseTypeDef = TypedDict(
+    "DescribeConfigurationRevisionResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -632,15 +633,15 @@ class FirehoseTypeDef(_RequiredFirehoseTypeDef, _OptionalFirehoseTypeDef):
     pass
 
 
-GetBootstrapBrokersRequestTypeDef = TypedDict(
-    "GetBootstrapBrokersRequestTypeDef",
+GetBootstrapBrokersRequestRequestTypeDef = TypedDict(
+    "GetBootstrapBrokersRequestRequestTypeDef",
     {
         "ClusterArn": str,
     },
 )
 
-GetBootstrapBrokersResponseResponseTypeDef = TypedDict(
-    "GetBootstrapBrokersResponseResponseTypeDef",
+GetBootstrapBrokersResponseTypeDef = TypedDict(
+    "GetBootstrapBrokersResponseTypeDef",
     {
         "BootstrapBrokerString": str,
         "BootstrapBrokerStringTls": str,
@@ -650,16 +651,16 @@ GetBootstrapBrokersResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetCompatibleKafkaVersionsRequestTypeDef = TypedDict(
-    "GetCompatibleKafkaVersionsRequestTypeDef",
+GetCompatibleKafkaVersionsRequestRequestTypeDef = TypedDict(
+    "GetCompatibleKafkaVersionsRequestRequestTypeDef",
     {
         "ClusterArn": str,
     },
     total=False,
 )
 
-GetCompatibleKafkaVersionsResponseResponseTypeDef = TypedDict(
-    "GetCompatibleKafkaVersionsResponseResponseTypeDef",
+GetCompatibleKafkaVersionsResponseTypeDef = TypedDict(
+    "GetCompatibleKafkaVersionsResponseTypeDef",
     {
         "CompatibleKafkaVersions": List["CompatibleKafkaVersionTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -697,14 +698,14 @@ KafkaVersionTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListClusterOperationsRequestTypeDef = TypedDict(
-    "_RequiredListClusterOperationsRequestTypeDef",
+_RequiredListClusterOperationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListClusterOperationsRequestRequestTypeDef",
     {
         "ClusterArn": str,
     },
 )
-_OptionalListClusterOperationsRequestTypeDef = TypedDict(
-    "_OptionalListClusterOperationsRequestTypeDef",
+_OptionalListClusterOperationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListClusterOperationsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -713,14 +714,15 @@ _OptionalListClusterOperationsRequestTypeDef = TypedDict(
 )
 
 
-class ListClusterOperationsRequestTypeDef(
-    _RequiredListClusterOperationsRequestTypeDef, _OptionalListClusterOperationsRequestTypeDef
+class ListClusterOperationsRequestRequestTypeDef(
+    _RequiredListClusterOperationsRequestRequestTypeDef,
+    _OptionalListClusterOperationsRequestRequestTypeDef,
 ):
     pass
 
 
-ListClusterOperationsResponseResponseTypeDef = TypedDict(
-    "ListClusterOperationsResponseResponseTypeDef",
+ListClusterOperationsResponseTypeDef = TypedDict(
+    "ListClusterOperationsResponseTypeDef",
     {
         "ClusterOperationInfoList": List["ClusterOperationInfoTypeDef"],
         "NextToken": str,
@@ -728,8 +730,8 @@ ListClusterOperationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListClustersRequestTypeDef = TypedDict(
-    "ListClustersRequestTypeDef",
+ListClustersRequestRequestTypeDef = TypedDict(
+    "ListClustersRequestRequestTypeDef",
     {
         "ClusterNameFilter": str,
         "MaxResults": int,
@@ -738,8 +740,8 @@ ListClustersRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListClustersResponseResponseTypeDef = TypedDict(
-    "ListClustersResponseResponseTypeDef",
+ListClustersResponseTypeDef = TypedDict(
+    "ListClustersResponseTypeDef",
     {
         "ClusterInfoList": List["ClusterInfoTypeDef"],
         "NextToken": str,
@@ -747,14 +749,14 @@ ListClustersResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListConfigurationRevisionsRequestTypeDef = TypedDict(
-    "_RequiredListConfigurationRevisionsRequestTypeDef",
+_RequiredListConfigurationRevisionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListConfigurationRevisionsRequestRequestTypeDef",
     {
         "Arn": str,
     },
 )
-_OptionalListConfigurationRevisionsRequestTypeDef = TypedDict(
-    "_OptionalListConfigurationRevisionsRequestTypeDef",
+_OptionalListConfigurationRevisionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListConfigurationRevisionsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -763,15 +765,15 @@ _OptionalListConfigurationRevisionsRequestTypeDef = TypedDict(
 )
 
 
-class ListConfigurationRevisionsRequestTypeDef(
-    _RequiredListConfigurationRevisionsRequestTypeDef,
-    _OptionalListConfigurationRevisionsRequestTypeDef,
+class ListConfigurationRevisionsRequestRequestTypeDef(
+    _RequiredListConfigurationRevisionsRequestRequestTypeDef,
+    _OptionalListConfigurationRevisionsRequestRequestTypeDef,
 ):
     pass
 
 
-ListConfigurationRevisionsResponseResponseTypeDef = TypedDict(
-    "ListConfigurationRevisionsResponseResponseTypeDef",
+ListConfigurationRevisionsResponseTypeDef = TypedDict(
+    "ListConfigurationRevisionsResponseTypeDef",
     {
         "NextToken": str,
         "Revisions": List["ConfigurationRevisionTypeDef"],
@@ -779,8 +781,8 @@ ListConfigurationRevisionsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListConfigurationsRequestTypeDef = TypedDict(
-    "ListConfigurationsRequestTypeDef",
+ListConfigurationsRequestRequestTypeDef = TypedDict(
+    "ListConfigurationsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -788,8 +790,8 @@ ListConfigurationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListConfigurationsResponseResponseTypeDef = TypedDict(
-    "ListConfigurationsResponseResponseTypeDef",
+ListConfigurationsResponseTypeDef = TypedDict(
+    "ListConfigurationsResponseTypeDef",
     {
         "Configurations": List["ConfigurationTypeDef"],
         "NextToken": str,
@@ -797,8 +799,8 @@ ListConfigurationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListKafkaVersionsRequestTypeDef = TypedDict(
-    "ListKafkaVersionsRequestTypeDef",
+ListKafkaVersionsRequestRequestTypeDef = TypedDict(
+    "ListKafkaVersionsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -806,8 +808,8 @@ ListKafkaVersionsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListKafkaVersionsResponseResponseTypeDef = TypedDict(
-    "ListKafkaVersionsResponseResponseTypeDef",
+ListKafkaVersionsResponseTypeDef = TypedDict(
+    "ListKafkaVersionsResponseTypeDef",
     {
         "KafkaVersions": List["KafkaVersionTypeDef"],
         "NextToken": str,
@@ -815,14 +817,14 @@ ListKafkaVersionsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListNodesRequestTypeDef = TypedDict(
-    "_RequiredListNodesRequestTypeDef",
+_RequiredListNodesRequestRequestTypeDef = TypedDict(
+    "_RequiredListNodesRequestRequestTypeDef",
     {
         "ClusterArn": str,
     },
 )
-_OptionalListNodesRequestTypeDef = TypedDict(
-    "_OptionalListNodesRequestTypeDef",
+_OptionalListNodesRequestRequestTypeDef = TypedDict(
+    "_OptionalListNodesRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -831,12 +833,14 @@ _OptionalListNodesRequestTypeDef = TypedDict(
 )
 
 
-class ListNodesRequestTypeDef(_RequiredListNodesRequestTypeDef, _OptionalListNodesRequestTypeDef):
+class ListNodesRequestRequestTypeDef(
+    _RequiredListNodesRequestRequestTypeDef, _OptionalListNodesRequestRequestTypeDef
+):
     pass
 
 
-ListNodesResponseResponseTypeDef = TypedDict(
-    "ListNodesResponseResponseTypeDef",
+ListNodesResponseTypeDef = TypedDict(
+    "ListNodesResponseTypeDef",
     {
         "NextToken": str,
         "NodeInfoList": List["NodeInfoTypeDef"],
@@ -844,14 +848,14 @@ ListNodesResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListScramSecretsRequestTypeDef = TypedDict(
-    "_RequiredListScramSecretsRequestTypeDef",
+_RequiredListScramSecretsRequestRequestTypeDef = TypedDict(
+    "_RequiredListScramSecretsRequestRequestTypeDef",
     {
         "ClusterArn": str,
     },
 )
-_OptionalListScramSecretsRequestTypeDef = TypedDict(
-    "_OptionalListScramSecretsRequestTypeDef",
+_OptionalListScramSecretsRequestRequestTypeDef = TypedDict(
+    "_OptionalListScramSecretsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -860,14 +864,14 @@ _OptionalListScramSecretsRequestTypeDef = TypedDict(
 )
 
 
-class ListScramSecretsRequestTypeDef(
-    _RequiredListScramSecretsRequestTypeDef, _OptionalListScramSecretsRequestTypeDef
+class ListScramSecretsRequestRequestTypeDef(
+    _RequiredListScramSecretsRequestRequestTypeDef, _OptionalListScramSecretsRequestRequestTypeDef
 ):
     pass
 
 
-ListScramSecretsResponseResponseTypeDef = TypedDict(
-    "ListScramSecretsResponseResponseTypeDef",
+ListScramSecretsResponseTypeDef = TypedDict(
+    "ListScramSecretsResponseTypeDef",
     {
         "NextToken": str,
         "SecretArnList": List[str],
@@ -875,15 +879,15 @@ ListScramSecretsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -981,16 +985,16 @@ PrometheusTypeDef = TypedDict(
     total=False,
 )
 
-RebootBrokerRequestTypeDef = TypedDict(
-    "RebootBrokerRequestTypeDef",
+RebootBrokerRequestRequestTypeDef = TypedDict(
+    "RebootBrokerRequestRequestTypeDef",
     {
         "BrokerIds": List[str],
         "ClusterArn": str,
     },
 )
 
-RebootBrokerResponseResponseTypeDef = TypedDict(
-    "RebootBrokerResponseResponseTypeDef",
+RebootBrokerResponseTypeDef = TypedDict(
+    "RebootBrokerResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
@@ -1063,8 +1067,8 @@ StorageInfoTypeDef = TypedDict(
     total=False,
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "Tags": Dict[str, str],
@@ -1089,16 +1093,16 @@ UnprocessedScramSecretTypeDef = TypedDict(
     total=False,
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "TagKeys": List[str],
     },
 )
 
-UpdateBrokerCountRequestTypeDef = TypedDict(
-    "UpdateBrokerCountRequestTypeDef",
+UpdateBrokerCountRequestRequestTypeDef = TypedDict(
+    "UpdateBrokerCountRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
@@ -1106,8 +1110,8 @@ UpdateBrokerCountRequestTypeDef = TypedDict(
     },
 )
 
-UpdateBrokerCountResponseResponseTypeDef = TypedDict(
-    "UpdateBrokerCountResponseResponseTypeDef",
+UpdateBrokerCountResponseTypeDef = TypedDict(
+    "UpdateBrokerCountResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
@@ -1115,8 +1119,8 @@ UpdateBrokerCountResponseResponseTypeDef = TypedDict(
     },
 )
 
-UpdateBrokerStorageRequestTypeDef = TypedDict(
-    "UpdateBrokerStorageRequestTypeDef",
+UpdateBrokerStorageRequestRequestTypeDef = TypedDict(
+    "UpdateBrokerStorageRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
@@ -1124,8 +1128,8 @@ UpdateBrokerStorageRequestTypeDef = TypedDict(
     },
 )
 
-UpdateBrokerStorageResponseResponseTypeDef = TypedDict(
-    "UpdateBrokerStorageResponseResponseTypeDef",
+UpdateBrokerStorageResponseTypeDef = TypedDict(
+    "UpdateBrokerStorageResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
@@ -1133,8 +1137,8 @@ UpdateBrokerStorageResponseResponseTypeDef = TypedDict(
     },
 )
 
-UpdateBrokerTypeRequestTypeDef = TypedDict(
-    "UpdateBrokerTypeRequestTypeDef",
+UpdateBrokerTypeRequestRequestTypeDef = TypedDict(
+    "UpdateBrokerTypeRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
@@ -1142,8 +1146,8 @@ UpdateBrokerTypeRequestTypeDef = TypedDict(
     },
 )
 
-UpdateBrokerTypeResponseResponseTypeDef = TypedDict(
-    "UpdateBrokerTypeResponseResponseTypeDef",
+UpdateBrokerTypeResponseTypeDef = TypedDict(
+    "UpdateBrokerTypeResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
@@ -1151,8 +1155,8 @@ UpdateBrokerTypeResponseResponseTypeDef = TypedDict(
     },
 )
 
-UpdateClusterConfigurationRequestTypeDef = TypedDict(
-    "UpdateClusterConfigurationRequestTypeDef",
+UpdateClusterConfigurationRequestRequestTypeDef = TypedDict(
+    "UpdateClusterConfigurationRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "ConfigurationInfo": "ConfigurationInfoTypeDef",
@@ -1160,8 +1164,8 @@ UpdateClusterConfigurationRequestTypeDef = TypedDict(
     },
 )
 
-UpdateClusterConfigurationResponseResponseTypeDef = TypedDict(
-    "UpdateClusterConfigurationResponseResponseTypeDef",
+UpdateClusterConfigurationResponseTypeDef = TypedDict(
+    "UpdateClusterConfigurationResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
@@ -1169,16 +1173,16 @@ UpdateClusterConfigurationResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateClusterKafkaVersionRequestTypeDef = TypedDict(
-    "_RequiredUpdateClusterKafkaVersionRequestTypeDef",
+_RequiredUpdateClusterKafkaVersionRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateClusterKafkaVersionRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
         "TargetKafkaVersion": str,
     },
 )
-_OptionalUpdateClusterKafkaVersionRequestTypeDef = TypedDict(
-    "_OptionalUpdateClusterKafkaVersionRequestTypeDef",
+_OptionalUpdateClusterKafkaVersionRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateClusterKafkaVersionRequestRequestTypeDef",
     {
         "ConfigurationInfo": "ConfigurationInfoTypeDef",
     },
@@ -1186,15 +1190,15 @@ _OptionalUpdateClusterKafkaVersionRequestTypeDef = TypedDict(
 )
 
 
-class UpdateClusterKafkaVersionRequestTypeDef(
-    _RequiredUpdateClusterKafkaVersionRequestTypeDef,
-    _OptionalUpdateClusterKafkaVersionRequestTypeDef,
+class UpdateClusterKafkaVersionRequestRequestTypeDef(
+    _RequiredUpdateClusterKafkaVersionRequestRequestTypeDef,
+    _OptionalUpdateClusterKafkaVersionRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateClusterKafkaVersionResponseResponseTypeDef = TypedDict(
-    "UpdateClusterKafkaVersionResponseResponseTypeDef",
+UpdateClusterKafkaVersionResponseTypeDef = TypedDict(
+    "UpdateClusterKafkaVersionResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
@@ -1202,15 +1206,15 @@ UpdateClusterKafkaVersionResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateConfigurationRequestTypeDef = TypedDict(
-    "_RequiredUpdateConfigurationRequestTypeDef",
+_RequiredUpdateConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateConfigurationRequestRequestTypeDef",
     {
         "Arn": str,
         "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
     },
 )
-_OptionalUpdateConfigurationRequestTypeDef = TypedDict(
-    "_OptionalUpdateConfigurationRequestTypeDef",
+_OptionalUpdateConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateConfigurationRequestRequestTypeDef",
     {
         "Description": str,
     },
@@ -1218,14 +1222,15 @@ _OptionalUpdateConfigurationRequestTypeDef = TypedDict(
 )
 
 
-class UpdateConfigurationRequestTypeDef(
-    _RequiredUpdateConfigurationRequestTypeDef, _OptionalUpdateConfigurationRequestTypeDef
+class UpdateConfigurationRequestRequestTypeDef(
+    _RequiredUpdateConfigurationRequestRequestTypeDef,
+    _OptionalUpdateConfigurationRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateConfigurationResponseResponseTypeDef = TypedDict(
-    "UpdateConfigurationResponseResponseTypeDef",
+UpdateConfigurationResponseTypeDef = TypedDict(
+    "UpdateConfigurationResponseTypeDef",
     {
         "Arn": str,
         "LatestRevision": "ConfigurationRevisionTypeDef",
@@ -1233,15 +1238,15 @@ UpdateConfigurationResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateMonitoringRequestTypeDef = TypedDict(
-    "_RequiredUpdateMonitoringRequestTypeDef",
+_RequiredUpdateMonitoringRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateMonitoringRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
     },
 )
-_OptionalUpdateMonitoringRequestTypeDef = TypedDict(
-    "_OptionalUpdateMonitoringRequestTypeDef",
+_OptionalUpdateMonitoringRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateMonitoringRequestRequestTypeDef",
     {
         "EnhancedMonitoring": EnhancedMonitoringType,
         "OpenMonitoring": "OpenMonitoringInfoTypeDef",
@@ -1251,14 +1256,14 @@ _OptionalUpdateMonitoringRequestTypeDef = TypedDict(
 )
 
 
-class UpdateMonitoringRequestTypeDef(
-    _RequiredUpdateMonitoringRequestTypeDef, _OptionalUpdateMonitoringRequestTypeDef
+class UpdateMonitoringRequestRequestTypeDef(
+    _RequiredUpdateMonitoringRequestRequestTypeDef, _OptionalUpdateMonitoringRequestRequestTypeDef
 ):
     pass
 
 
-UpdateMonitoringResponseResponseTypeDef = TypedDict(
-    "UpdateMonitoringResponseResponseTypeDef",
+UpdateMonitoringResponseTypeDef = TypedDict(
+    "UpdateMonitoringResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
